@@ -1,33 +1,26 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import hashlib
 import itertools
-import re
+import urllib.parse
 
 from .common import InfoExtractor, SearchInfoExtractor
-from ..compat import (
-    compat_str,
-    compat_urllib_parse,
-)
+from .youtube import YoutubeIE
 from ..utils import (
-    clean_html,
     ExtractorError,
+    clean_html,
     int_or_none,
     mimetype2ext,
     parse_iso8601,
-    smuggle_url,
+    traverse_obj,
     try_get,
     url_or_none,
 )
 
-from .brightcove import BrightcoveNewIE
-from .youtube import YoutubeIE
-
 
 class YahooIE(InfoExtractor):
     IE_DESC = 'Yahoo screen and movies'
     _VALID_URL = r'(?P<url>https?://(?:(?P<country>[a-zA-Z]{2}(?:-[a-zA-Z]{2})?|malaysia)\.)?(?:[\da-zA-Z_-]+\.)?yahoo\.com/(?:[^/]+/)*(?P<id>[^?&#]*-[0-9]+(?:-[a-z]+)?)\.html)'
+    _EMBED_REGEX = [r'<iframe[^>]+?src=(["\'])(?P<url>https?://(?:screen|movies)\.yahoo\.com/.+?\.html\?format=embed)\1']
+
     _TESTS = [{
         'url': 'http://screen.yahoo.com/julian-smith-travis-legg-watch-214727115.html',
         'info_dict': {
@@ -246,8 +239,6 @@ class YahooIE(InfoExtractor):
         if not formats and msg == 'geo restricted':
             self.raise_geo_restricted(metadata_available=True)
 
-        self._sort_formats(formats)
-
         thumbnails = []
         for thumb in video.get('thumbnails', []):
             thumb_url = thumb.get('url')
@@ -317,7 +308,7 @@ class YahooIE(InfoExtractor):
 
             if items.get('markup'):
                 entries.extend(
-                    self.url_result(yt_url) for yt_url in YoutubeIE._extract_urls(items['markup']))
+                    self.url_result(yt_url) for yt_url in YoutubeIE._extract_embed_urls(url, items['markup']))
 
             return self.playlist_result(
                 entries, item.get('uuid'),
@@ -336,7 +327,7 @@ class YahooSearchIE(SearchInfoExtractor):
 
     def _search_results(self, query):
         for pagenum in itertools.count(0):
-            result_url = 'http://video.search.yahoo.com/search/?p=%s&fr=screen&o=js&gs=0&b=%d' % (compat_urllib_parse.quote_plus(query), pagenum * 30)
+            result_url = 'http://video.search.yahoo.com/search/?p=%s&fr=screen&o=js&gs=0&b=%d' % (urllib.parse.quote_plus(query), pagenum * 30)
             info = self._download_json(result_url, query,
                                        note='Downloading results page ' + str(pagenum + 1))
             yield from (self.url_result(result['rurl']) for result in info['results'])
@@ -344,151 +335,23 @@ class YahooSearchIE(SearchInfoExtractor):
                 break
 
 
-class YahooGyaOPlayerIE(InfoExtractor):
-    IE_NAME = 'yahoo:gyao:player'
-    _VALID_URL = r'https?://(?:gyao\.yahoo\.co\.jp/(?:player|episode(?:/[^/]+)?)|streaming\.yahoo\.co\.jp/c/y)/(?P<id>\d+/v\d+/v\d+|[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12})'
-    _TESTS = [{
-        'url': 'https://gyao.yahoo.co.jp/player/00998/v00818/v0000000000000008564/',
-        'info_dict': {
-            'id': '5993125228001',
-            'ext': 'mp4',
-            'title': 'フューリー　【字幕版】',
-            'description': 'md5:21e691c798a15330eda4db17a8fe45a5',
-            'uploader_id': '4235717419001',
-            'upload_date': '20190124',
-            'timestamp': 1548294365,
-        },
-        'params': {
-            # m3u8 download
-            'skip_download': True,
-        },
-    }, {
-        'url': 'https://streaming.yahoo.co.jp/c/y/01034/v00133/v0000000000000000706/',
-        'only_matching': True,
-    }, {
-        'url': 'https://gyao.yahoo.co.jp/episode/%E3%81%8D%E3%81%AE%E3%81%86%E4%BD%95%E9%A3%9F%E3%81%B9%E3%81%9F%EF%BC%9F%20%E7%AC%AC2%E8%A9%B1%202019%2F4%2F12%E6%94%BE%E9%80%81%E5%88%86/5cb02352-b725-409e-9f8d-88f947a9f682',
-        'only_matching': True,
-    }, {
-        'url': 'https://gyao.yahoo.co.jp/episode/5fa1226c-ef8d-4e93-af7a-fd92f4e30597',
-        'only_matching': True,
-    }]
-    _GEO_BYPASS = False
-
-    def _real_extract(self, url):
-        video_id = self._match_id(url).replace('/', ':')
-        headers = self.geo_verification_headers()
-        headers['Accept'] = 'application/json'
-        resp = self._download_json(
-            'https://gyao.yahoo.co.jp/apis/playback/graphql', video_id, query={
-                'appId': 'dj00aiZpPUNJeDh2cU1RazU3UCZzPWNvbnN1bWVyc2VjcmV0Jng9NTk-',
-                'query': '''{
-  content(parameter: {contentId: "%s", logicaAgent: PC_WEB}) {
-    video {
-      delivery {
-        id
-      }
-      title
-    }
-  }
-}''' % video_id,
-            }, headers=headers)
-        content = resp['data']['content']
-        if not content:
-            msg = resp['errors'][0]['message']
-            if msg == 'not in japan':
-                self.raise_geo_restricted(countries=['JP'])
-            raise ExtractorError(msg)
-        video = content['video']
-        return {
-            '_type': 'url_transparent',
-            'id': video_id,
-            'title': video['title'],
-            'url': smuggle_url(
-                'http://players.brightcove.net/4235717419001/SyG5P0gjb_default/index.html?videoId=' + video['delivery']['id'],
-                {'geo_countries': ['JP']}),
-            'ie_key': BrightcoveNewIE.ie_key(),
-        }
-
-
-class YahooGyaOIE(InfoExtractor):
-    IE_NAME = 'yahoo:gyao'
-    _VALID_URL = r'https?://(?:gyao\.yahoo\.co\.jp/(?:p|title(?:/[^/]+)?)|streaming\.yahoo\.co\.jp/p/y)/(?P<id>\d+/v\d+|[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12})'
-    _TESTS = [{
-        'url': 'https://gyao.yahoo.co.jp/title/%E3%82%BF%E3%82%A4%E3%83%A0%E3%83%9C%E3%82%AB%E3%83%B3%E3%82%B7%E3%83%AA%E3%83%BC%E3%82%BA%20%E3%83%A4%E3%83%83%E3%82%BF%E3%83%BC%E3%83%9E%E3%83%B3/5f60ceb3-6e5e-40ef-ba40-d68b598d067f',
-        'info_dict': {
-            'id': '5f60ceb3-6e5e-40ef-ba40-d68b598d067f',
-        },
-        'playlist_mincount': 80,
-    }, {
-        'url': 'https://gyao.yahoo.co.jp/p/00449/v03102/',
-        'only_matching': True,
-    }, {
-        'url': 'https://streaming.yahoo.co.jp/p/y/01034/v00133/',
-        'only_matching': True,
-    }, {
-        'url': 'https://gyao.yahoo.co.jp/title/%E3%81%97%E3%82%83%E3%81%B9%E3%81%8F%E3%82%8A007/5b025a49-b2e5-4dc7-945c-09c6634afacf',
-        'only_matching': True,
-    }, {
-        'url': 'https://gyao.yahoo.co.jp/title/5b025a49-b2e5-4dc7-945c-09c6634afacf',
-        'only_matching': True,
-    }]
-
-    def _entries(self, program_id):
-        page = 1
-        while True:
-            playlist = self._download_json(
-                f'https://gyao.yahoo.co.jp/api/programs/{program_id}/videos?page={page}', program_id,
-                note=f'Downloading JSON metadata page {page}')
-            if not playlist:
-                break
-            for video in playlist['videos']:
-                video_id = video.get('id')
-                if not video_id:
-                    continue
-                if video.get('streamingAvailability') == 'notYet':
-                    continue
-                yield self.url_result(
-                    'https://gyao.yahoo.co.jp/player/%s/' % video_id.replace(':', '/'),
-                    YahooGyaOPlayerIE.ie_key(), video_id)
-            if playlist.get('ended'):
-                break
-            page += 1
-
-    def _real_extract(self, url):
-        program_id = self._match_id(url).replace('/', ':')
-        return self.playlist_result(self._entries(program_id), program_id)
-
-
 class YahooJapanNewsIE(InfoExtractor):
     IE_NAME = 'yahoo:japannews'
     IE_DESC = 'Yahoo! Japan News'
-    _VALID_URL = r'https?://(?P<host>(?:news|headlines)\.yahoo\.co\.jp)[^\d]*(?P<id>\d[\d-]*\d)?'
+    _VALID_URL = r'https?://news\.yahoo\.co\.jp/(?:articles|feature)/(?P<id>[a-zA-Z0-9]+)'
     _GEO_COUNTRIES = ['JP']
     _TESTS = [{
-        'url': 'https://headlines.yahoo.co.jp/videonews/ann?a=20190716-00000071-ann-int',
+        'url': 'https://news.yahoo.co.jp/articles/a70fe3a064f1cfec937e2252c7fc6c1ba3201c0e',
         'info_dict': {
-            'id': '1736242',
+            'id': 'a70fe3a064f1cfec937e2252c7fc6c1ba3201c0e',
             'ext': 'mp4',
-            'title': 'ムン大統領が対日批判を強化“現金化”効果は？（テレビ朝日系（ANN）） - Yahoo!ニュース',
-            'description': '韓国の元徴用工らを巡る裁判の原告が弁護士が差し押さえた三菱重工業の資産を売却して - Yahoo!ニュース(テレビ朝日系（ANN）)',
-            'thumbnail': r're:^https?://.*\.[a-zA-Z\d]{3,4}$',
+            'title': '【独自】安倍元総理「国葬」中止求め“脅迫メール”…「子ども誘拐」“送信者”を追跡',
+            'description': 'md5:1c06974575f930f692d8696fbcfdc546',
+            'thumbnail': r're:https://.+',
         },
         'params': {
             'skip_download': True,
         },
-    }, {
-        # geo restricted
-        'url': 'https://headlines.yahoo.co.jp/hl?a=20190721-00000001-oxv-l04',
-        'only_matching': True,
-    }, {
-        'url': 'https://headlines.yahoo.co.jp/videonews/',
-        'only_matching': True,
-    }, {
-        'url': 'https://news.yahoo.co.jp',
-        'only_matching': True,
-    }, {
-        'url': 'https://news.yahoo.co.jp/byline/hashimotojunji/20190628-00131977/',
-        'only_matching': True,
     }, {
         'url': 'https://news.yahoo.co.jp/feature/1356',
         'only_matching': True
@@ -497,11 +360,7 @@ class YahooJapanNewsIE(InfoExtractor):
     def _extract_formats(self, json_data, content_id):
         formats = []
 
-        video_data = try_get(
-            json_data,
-            lambda x: x['ResultSet']['Result'][0]['VideoUrlSet']['VideoUrl'],
-            list)
-        for vid in video_data or []:
+        for vid in traverse_obj(json_data, ('ResultSet', 'Result', ..., 'VideoUrlSet', 'VideoUrl', ...)) or []:
             delivery = vid.get('delivery')
             url = url_or_none(vid.get('Url'))
             if not delivery or not url:
@@ -514,73 +373,58 @@ class YahooJapanNewsIE(InfoExtractor):
             else:
                 formats.append({
                     'url': url,
-                    'format_id': 'http-%s' % compat_str(vid.get('bitrate', '')),
+                    'format_id': f'http-{vid.get("bitrate")}',
                     'height': int_or_none(vid.get('height')),
                     'width': int_or_none(vid.get('width')),
                     'tbr': int_or_none(vid.get('bitrate')),
                 })
         self._remove_duplicate_formats(formats)
-        self._sort_formats(formats)
 
         return formats
 
     def _real_extract(self, url):
-        mobj = self._match_valid_url(url)
-        host = mobj.group('host')
-        display_id = mobj.group('id') or host
+        video_id = self._match_id(url)
+        webpage = self._download_webpage(url, video_id)
+        preloaded_state = self._search_json(r'__PRELOADED_STATE__\s*=', webpage, 'preloaded state', video_id)
 
-        webpage = self._download_webpage(url, display_id)
-
-        title = self._html_search_meta(
-            ['og:title', 'twitter:title'], webpage, 'title', default=None
-        ) or self._html_search_regex('<title>([^<]+)</title>', webpage, 'title')
-
-        if display_id == host:
-            # Headline page (w/ multiple BC playlists) ('news.yahoo.co.jp', 'headlines.yahoo.co.jp/videonews/', ...)
-            stream_plists = re.findall(r'plist=(\d+)', webpage) or re.findall(r'plist["\']:\s*["\']([^"\']+)', webpage)
-            entries = [
-                self.url_result(
-                    smuggle_url(
-                        'http://players.brightcove.net/5690807595001/HyZNerRl7_default/index.html?playlistId=%s' % plist_id,
-                        {'geo_countries': ['JP']}),
-                    ie='BrightcoveNew', video_id=plist_id)
-                for plist_id in stream_plists]
-            return self.playlist_result(entries, playlist_title=title)
-
-        # Article page
-        description = self._html_search_meta(
-            ['og:description', 'description', 'twitter:description'],
-            webpage, 'description', default=None)
-        thumbnail = self._og_search_thumbnail(
-            webpage, default=None) or self._html_search_meta(
-            'twitter:image', webpage, 'thumbnail', default=None)
-        space_id = self._search_regex([
-            r'<script[^>]+class=["\']yvpub-player["\'][^>]+spaceid=([^&"\']+)',
-            r'YAHOO\.JP\.srch\.\w+link\.onLoad[^;]+spaceID["\' ]*:["\' ]+([^"\']+)',
-            r'<!--\s+SpaceID=(\d+)'
-        ], webpage, 'spaceid')
-
-        content_id = self._search_regex(
-            r'<script[^>]+class=["\']yvpub-player["\'][^>]+contentid=(?P<contentid>[^&"\']+)',
-            webpage, 'contentid', group='contentid')
+        content_id = traverse_obj(
+            preloaded_state, ('articleDetail', 'paragraphs', ..., 'objectItems', ..., 'video', 'vid'),
+            get_all=False, expected_type=int)
+        if content_id is None:
+            raise ExtractorError('This article does not contain a video', expected=True)
 
+        HOST = 'news.yahoo.co.jp'
+        space_id = traverse_obj(preloaded_state, ('pageData', 'spaceId'), expected_type=str)
         json_data = self._download_json(
-            'https://feapi-yvpub.yahooapis.jp/v1/content/%s' % content_id,
-            content_id,
-            query={
+            f'https://feapi-yvpub.yahooapis.jp/v1/content/{content_id}',
+            video_id, query={
                 'appid': 'dj0zaiZpPVZMTVFJR0FwZWpiMyZzPWNvbnN1bWVyc2VjcmV0Jng9YjU-',
                 'output': 'json',
-                'space_id': space_id,
-                'domain': host,
-                'ak': hashlib.md5('_'.join((space_id, host)).encode()).hexdigest(),
+                'domain': HOST,
+                'ak': hashlib.md5('_'.join((space_id, HOST)).encode()).hexdigest() if space_id else '',
                 'device_type': '1100',
             })
-        formats = self._extract_formats(json_data, content_id)
+
+        title = (
+            traverse_obj(preloaded_state,
+                         ('articleDetail', 'headline'), ('pageData', 'pageParam', 'title'),
+                         expected_type=str)
+            or self._html_search_meta(('og:title', 'twitter:title'), webpage, 'title', default=None)
+            or self._html_extract_title(webpage))
+        description = (
+            traverse_obj(preloaded_state, ('pageData', 'description'), expected_type=str)
+            or self._html_search_meta(
+                ('og:description', 'description', 'twitter:description'),
+                webpage, 'description', default=None))
+        thumbnail = (
+            traverse_obj(preloaded_state, ('pageData', 'ogpImage'), expected_type=str)
+            or self._og_search_thumbnail(webpage, default=None)
+            or self._html_search_meta('twitter:image', webpage, 'thumbnail', default=None))
 
         return {
-            'id': content_id,
+            'id': video_id,
             'title': title,
             'description': description,
             'thumbnail': thumbnail,
-            'formats': formats,
+            'formats': self._extract_formats(json_data, video_id),
         }
